rnalysis.filtering.DESeqFilter.split\_by\_bigtable\_group
=========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.split_by_bigtable_group